package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysProject;

public interface ISysProjectService
{
    public SysProject selectSysProjectById(Long id);

    public List<SysProject> selectSysProjectList(SysProject sysProject);

    public int insertSysProject(SysProject sysProject);

    public int updateSysProject(SysProject sysProject);

    public int deleteSysProjectByIds(Long[] ids);

    public int deleteSysProjectById(Long id);
}
